Crate hexchess

Re-exports

pub use constants::Color;
pub use constants::Piece;
pub use hexchess::hexchess::Hexchess;
pub use hexchess::san::San;
pub use hexchess::utils::index;
pub use hexchess::utils::position;

Modules

constants
hexchess
macros

Macros

h
position index aliases
s

Functions

apply
Apply a whitespace separated sequence of move to Hexchess object.
apply_move
Apply San object to a Hexchess object.
apply_move_unsafe
Apply San object to a Hexchess object, regardless of turn or legality.
create_hexchess
Create a blank Hexchess object.
current_moves
Get current legal moves.
find_king
Find the king of a given color.
get
Get piece at position
init_hexchess
Create Hexchess object at the initial position.
is_check
Test if the board is in check.
is_checkmate
Test if the board is in checkmate.
is_stalemate
Test if the board is in stalemate.
moves_from
Get legal moves from a position index.
moves_from_unsafe
Get all possible moves, including ones that result in self-check.
parse_hexchess
Parse Hexchess object from Forsyth–Edwards Notation.
parse_san
Parse San object from string.
stringify_hexchess
Convert Hexchess object to string using Forsyth-Edwards Notation.
stringify_san
Convert San object to string.